==> tinycobol-0.61.tar.gz: tinycobol-0.61/compiler/hthelp.h <==
/* 
 *  Copyright (C) 2001, 2000, 1999 David Essex
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *  
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with this software; see the file COPYING.  If not, write to
 *  the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *  Boston, MA 02111-1307 USA
 */


/*
    -o <file>      Specify output file name (default name a.out)\n
    -fpic          Generate position independent code, if possible
*/

#ifndef _HTHELP_H
#define _HTHELP_H

#ifdef TCOB_LANGUAGE_en

#define HTG_OPTIONS     "Compiler specific options:\n"\
"  -h             Help (display this listing)\n"\
"  -a             Create static library; Preprocess, compile, assemble and archive\n"\
"  -B <mode>      Specify libraries binding mode ( static or dynamic )\n"\
"  -c             Preprocess, compile and assemble, but do not link\n"\
"  -E             Output preprocessor to standard output only; do not compile, assemble or link\n"\
"  -g             Generate compiler debugging output\n"\
"  -l <name>      Add library name to link step\n"\
"  -L <dir>       Add directory to library search path\n"\
"  -m <name>      Create shared library; Preprocess, compile, assemble and link\n"\
"  -n             Don't actually run any commands; just print them\n"\
"  -o <file>      Specify output file name\n"\
"  -S             Preprocess, compile (generate assembler code) only; do not assemble or link\n"\
"  -v             Generate verbose compiler output\n"\
"  -V             Display compiler version information and exit\n"\
"  -Wl,<options>  Pass comma-separated <options> on to the linker\n"\
"  -x             Create executable; Preprocess, compile, assemble and link\n"\
"  -z             Generate very verbose compiler output\n"\
"COBOL specific options:\n"\
"  -C             Make all COBOL calls dynamic \n"\
"  -D             Include COBOL source debugging lines \n"\
"  -F             Input source is in standard fixed column format\n"\
"  -I <dir>       Add directory to the end of the include (copybooks) search paths\n"\
"  -P             Generate output listing file\n"\
"  -T <num>       Expand tabs to number of space(s) (default T=8)\n"\
"  -X             Input source is in free format (default format)\n"\
"\n"
#endif

#ifdef TCOB_LANGUAGE_fr

#define HTG_OPTIONS     "Options spcifiques au compilateur:\n"\
"  -h             Affiche l'aide\n"\
"  -a             Cre une librairie statique; prprocde, compile, assemble et archive\n"\
"  -B <mode>      Spcifie le mode de liens (statique/dynamique)\n"\
"  -c             Compile un module objet li statiqueme\n"\
"  -E             Sort seulement le rsultat du prtraitement sur la sortie standard; ne compile pas, ni n'assemble ou lie \n"\
"  -g             Gnre les informations de dbogage\n"\
"  -l <nom>       Ajoute le nom de la librairie  l'tape de liens \n"\
"  -L <chemin>    Ajoute le rpertoire  la liste de recherche des librairies\n"\
"  -m <nom>       Cre une librairie partage; prprocde, compile, assemble et lie\n"\
"  -n             N'excute pas les commandes; les montre seulement\n"\
"  -o <fichier>   Spcifie le fichier de sortie\n"\
"  -S             Prprocde, compile seulement (gnre le code assembleur); n'assemble pas, ni ne lie\n"\
"  -v             Demande une sortie verbeuse du compilateur\n"\
"  -V             Affiche les informations de version du compilateur et sort\n"\
"  -Wl,<options>  Passe une liste d'<options> spare par virgule  l'diteur de liens\n"\
"  -x             Compile un module excutable\n"\
"  -z             Demande une sortie trs verbeuse du compilateur\n"\
"Options spcifiques  COBOL:\n"\
"  -C             Rends tous les appels COBOL dynamiques\n"\
"  -D             Inclut les lignes sources pour le dbogage\n"\
"  -F             Dclare l'entre comme du format standard (colonnage fixe)\n"\
"  -I <chemin>    Dfinit le chemin de recherche des copy (dfaut -I./).\n"\
"                 Le chemin peut tre soit un seul rpertoire, soit une liste de rpertoires\n"\
"                 spare par un `:' (`;' sur la plateforme Win32). \n"\
"  -P             Gnre un fichier liste\n"\
"  -T <nombre>    Transforme les tabulations en <nombre> d'espaces (dfaut T=8)\n"\
"  -X             Dclare l'entre comme du format libre X/Open (format par dfaut)\n"\
"\n"
#endif

#ifdef TCOB_LANGUAGE_it

#define HTG_OPTIONS     "Opzioni compiler specifiche:\n"\
"  -h             Visualizza l'aiuto\n"\
"  -a             Crea libreria statica; Preprocessa, compila, assembla e comprime\n"\
"  -B <mode>      Specifica la modalita` di collegamento (statica/dinamica)\n"\
"  -c             Compila generando un modulo oggetto linkato staticamente\n"\
"  -E             Invoca il preprocessore inviando il risultato nello 'standard output'\n"\
"                 Non compila, ne` assembla o linka\n"\
"  -g             Genera un file utilizzabile per il debugging\n"\
"  -l <nome>      Aggiungi la libreria 'nome' nella fase di link\n"\
"  -L <dir>       Aggiungi la cartella 'dir' nel percorso di ricerca delle librerie\n"\
"  -m <nome>      Crea una libreria d'uso comune (shared); preprocessa, compila, assembla e linka\n"\
"  -n             Non esegue alcun comando; visualizza solo cio` che farebbe\n"\
"  -o <file>      Specifica il file da genereare\n"\
"  -S             Preprocessa, compila (genera codice assembler) solo; non assembla o linka\n"\
"  -v             Genera messaggi estesi durante la compilazione\n"\
"  -V             Visualizza la versione del compilatore and esce\n"\
"  -Wl,<opzioni>  Passa  (separate da virgola) al linker\n"\
"  -x             Genera un modulo eseguibile\n"\
"  -z             Genera messaggi molto estesi durante la compilazione\n"\
"Opzioni specifiche COBOL:\n"\
"  -C             Rendi tutte le 'calls' COBOL dinamiche\n"\
"  -D             Includi le linee di sorgente per il debugging\n"\
"  -F             Il sorgente in ingresso e` formattato in modalita` standard (fixed column)\n"\
"  -I <dir>       Definisce le cartelle 'path' di ricerca delle 'include' (copybooks).\n"\
"                 Il percorso puo` essere sia una singola cartella, sia un elenco di\n"\
"                 cartelle separate da ':' (';' su piattaforma Win32).\n"\
"                 La cartella di ricerca di default e` la cartella corrente (./).\n"\
"  -P             Genera un listato di compilazione\n"\
"  -T <num>       Converti i 'tabs' in 'num' spazi (default T=8)\n"\
"  -X             Il sorgente in ingresso ha la formattazione libera (X/Open free format) (default format)\n"\
"\n"
#endif

#ifdef TCOB_LANGUAGE_pt_BR

#define HTG_OPTIONS     "Opcoes especificas do Compilador:\n"\
"  -h             Mostra ajuda\n"\
"  -a             Cria biblioteca estatica; pre-processa, compila, assembla e arquiva\n"\
"  -B <modo>      modo especifico para aglutinacao (estatica/dinamica)\n"\
"  -c             Compilacao para um modulo de objeto estaticamente linkado\n"\
"  -E             Saida do preprocessador para saida padrao apenas; nao compila, assembla ou linka\n"\
"  -g             Gera saida de debug de compilacao\n"\
"  -l <arquivo>   Adiciona biblioteca na linkedicao\n"\
"  -L <diretorio> Adiciona diretorio ao caminho de procura de bibliotecas\n"\
"  -m <arquivo>   Cria biblioteca dinamica; pre-processa, compila, assembla e linka\n"\
"  -n             Na~o executa nenhum comando, deve mostrar a compilacao\n"\
"  -o <arquivo>   Especifica nome do executavel (padrao de entrada x extensao)\n"\
"  -S             Preprocessa, compila(gera codigo assembler) somente; nao assembla ou linka\n"\
"  -v             Gera saida do compilador verbosa\n"\
"  -V             Mostra informacoes da versao do compilador e sai\n"\
"  -Wl,<opcoes>   Passar opcoes separadas por virgula ao linkeditor\n"\
"  -x             Compilacao para criar um executavel\n"\
"  -z             Gera saida do compilador verbosa\n"\
"Opcoes especificas do COBOL:\n"\
"  -C             Faz todas as chamadas dinamicas COBOL\n"\
"  -D             Inclui linhas de debug no fonte\n"\
"  -F             Fonte de entrada esta em formato de coluna fixa padrao\n"\
"  -I <diretorio> Define inclusao(copybooks) de caminhos de procura. (padrao -I./)\n"\
"                 O caminho pode ser um simples diretorio, ou uma lista de diretorios separados por um ':'\n"\
"  -P             Gera arquivo de saida listado\n"\
"  -T <num>       <Expande tabs para um numero de espacos (padrao T=8)\n"\
"  -X             Arquivo de entrada esta em formato livre X/Open (formato padrao)\n"\
"\n"
#endif

#ifdef TCOB_LANGUAGE_es

#define HTG_OPTIONS     "Opciones especficas del compilador:\n"\
"  -h             Ayuda (muestra este listado)\n"\
"  -a             Crea una librera esttica; Preprocesar, compilar, ensamblar y archivar\n"\
"  -B <mode>      Especificar el modo para enlazado (static o dynamic)\n"\
"  -c             Proprocesa, compila y ensambla, pero no enlaza\n"\
"  -E             Muestra solo la salida del preprocesador a salida estandard; no compila, ensambla o enlaza\n"\
"  -g             Generar salida de compilador para debug\n"\
"  -l <name>      Aade la librera al enlazado\n"\
"  -L <dir>       Aade el directorio al camino de bsqueda de libreras\n"\
"  -m <name>      Crea una librera compartida; Preprocesa, compila, ensambla y enlaza\n"\
"  -n             No ejecuta ningn comando; solo los muestra\n"\
"  -o <file>      Especifica el nombre del fichero de salida\n"\
"  -S             Solo preprocesar y compilar (genera ensablador); no ensambla o enlaza\n"\
"  -v             Genera salida del compilador detallada\n"\
"  -V             Muestra la versin del compilador y termina\n"\
"  -Wl,<options>  Pasa <opciones>, separadas por comas, al enlazador\n"\
"  -x             Crea un ejecutable; preprocesa, compila, ensambla y enlaza\n"\
"  -z             Genera la salida del compilador muy detallada\n"\
"Opciones especficas de COBOL:\n"\
"  -C             Hace todas las llamadas de COBOL dinmicas\n"\
"  -D             Incluye lineas del fuente para debug\n"\
"  -F             El fuente de entrada est en formato estndar de columnas fijas\n"\
"  -I <dir>       Aade el directorio al final del camino de bsqueda de copybooks\n"\
"  -P             Genera un fichero listado de la salida\n"\
"  -T <num>       Expande los tabuladores a un nmero de espacios (por defecto T=8)\n"\
"  -X             El fichero de entrada est en formato libre X/Open (formato por defecto)\n"\
"\n"
#endif

#endif

==> tinycobol-0.63.tar.gz: tinycobol-0.63/compiler/hthelp.h <==
/* 
 *  Copyright (C) 2001, 2000, 1999 David Essex
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *  
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with this software; see the file COPYING.  If not, write to
 *  the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *  Boston, MA 02111-1307 USA
 */


/*
    -o <file>      Specify output file name (default name a.out)\n
    -fpic          Generate position independent code, if possible
*/

#ifndef _HTHELP_H
#define _HTHELP_H

//#define TCOB_LANGUAGE_@tcob_lang@       1

#ifdef TCOB_LANGUAGE_en

#define HTG_OPTIONS     "Compiler specific options:\n"\
"  -h             Help (display this listing)\n"\
"  -a             Create static library; Preprocess, compile, assemble and archive\n"\
"  -B <mode>      Specify libraries binding mode ( static or dynamic )\n"\
"  -c             Preprocess, compile and assemble, but do not link\n"\
"  -e <name>      Specify entry point name (first program to execute)\n"\
"  -E             Output preprocessor to standard output only; do not compile, assemble or link\n"\
"  -g             Generate compiler debugging output\n"\
"  -l <name>      Add library name to link step\n"\
"  -L <dir>       Add directory to library search path\n"\
"  -m <name>      Create shared library; Preprocess, compile, assemble and link\n"\
"  -M <option>    Specify main entry point option (auto|first|none)\n"\
"  -n             Don't actually run any commands; just print them\n"\
"  -o <file>      Specify output file name\n"\
"  -S             Preprocess, compile (generate assembler code) only; do not assemble or link\n"\
"  -v             Generate verbose compiler output\n"\
"  -V             Display compiler version information and exit\n"\
"  -Wl,<options>  Pass comma-separated <options> on to the linker\n"\
"  -x             Create executable; Preprocess, compile, assemble and link\n"\
"  -z             Generate very verbose compiler output\n"\
"COBOL specific options:\n"\
"  -C             Make all COBOL calls dynamic \n"\
"  -D             Include COBOL source debugging lines \n"\
"  -F             Input source is in standard fixed column format\n"\
"  -I <dir>       Add directory to the end of the include (copybooks) search paths\n"\
"  -P             Generate output listing file\n"\
"  -T <num>       Expand tabs to number of space(s) (default T=8)\n"\
"  -X             Input source is in free format\n"\
"\n"
#endif

#ifdef TCOB_LANGUAGE_fr

#define HTG_OPTIONS     "Options spcifiques au compilateur:\n"\
"  -h             Affiche l'aide\n"\
"  -a             Cre une librairie statique; prprocde, compile, assemble et archive\n"\
"  -B <mode>      Spcifie le mode de liens (statique/dynamique)\n"\
"  -c             Compile un module objet li statiqueme\n"\
"  -e <name>      Specify entry point name (first program to execute)\n"\
"  -E             Sort seulement le rsultat du prtraitement sur la sortie standard; ne compile pas, ni n'assemble ou lie \n"\
"  -g             Gnre les informations de dbogage\n"\
"  -l <nom>       Ajoute le nom de la librairie  l'tape de liens \n"\
"  -L <chemin>    Ajoute le rpertoire  la liste de recherche des librairies\n"\
"  -m <nom>       Cre une librairie partage; prprocde, compile, assemble et lie\n"\
"  -M <option>    Specify main entry point option (auto|first|none)\n"\
"  -n             N'excute pas les commandes; les montre seulement\n"\
"  -o <fichier>   Spcifie le fichier de sortie\n"\
"  -S             Prprocde, compile seulement (gnre le code assembleur); n'assemble pas, ni ne lie\n"\
"  -t             Conserve les fichiers intermdiaires\n"\
"  -v             Demande une sortie verbeuse du compilateur\n"\
"  -V             Affiche les informations de version du compilateur et sort\n"\
"  -Wl,<options>  Passe une liste d'<options> spare par virgule  l'diteur de liens\n"\
"  -x             Compile un module excutable\n"\
"  -z             Demande une sortie trs verbeuse du compilateur\n"\
"Options spcifiques  COBOL:\n"\
"  -C             Rends tous les appels COBOL dynamiques\n"\
"  -D             Inclut les lignes sources pour le dbogage\n"\
"  -F             Dclare l'entre comme du format standard (colonnage fixe)\n"\
"  -I <chemin>    Dfinit le chemin de recherche des copy (dfaut -I./).\n"\
"                 Le chemin peut tre soit un seul rpertoire, soit une liste de rpertoires\n"\
"                 spare par un `:' (`;' sur la plateforme Win32). \n"\
"  -P             Gnre un fichier liste\n"\
"  -T <nombre>    Transforme les tabulations en <nombre> d'espaces (dfaut T=8)\n"\
"  -X             Dclare l'entre comme du format libre X/Open (format par dfaut)\n"\
"\n"
#endif

#ifdef TCOB_LANGUAGE_it

#define HTG_OPTIONS     "Opzioni compiler specifiche:\n"\
"  -h             Visualizza l'aiuto\n"\
"  -a             Crea libreria statica; Preprocessa, compila, assembla e comprime\n"\
"  -B <mode>      Specifica la modalita` di collegamento (statica/dinamica)\n"\
"  -c             Compila generando un modulo oggetto linkato staticamente\n"\
"  -e <name>      Specify entry point name (first program to execute)\n"\
"  -E             Invoca il preprocessore inviando il risultato nello 'standard output'\n"\
"                 Non compila, ne` assembla o linka\n"\
"  -g             Genera un file utilizzabile per il debugging\n"\
"  -l <nome>      Aggiungi la libreria 'nome' nella fase di link\n"\
"  -L <dir>       Aggiungi la cartella 'dir' nel percorso di ricerca delle librerie\n"\
"  -m <nome>      Crea una libreria d'uso comune (shared); preprocessa, compila, assembla e linka\n"\
"  -M <option>    Specify main entry point option (auto|first|none)\n"\
"  -n             Non esegue alcun comando; visualizza solo cio` che farebbe\n"\
"  -o <file>      Specifica il file da genereare\n"\
"  -S             Preprocessa, compila (genera codice assembler) solo; non assembla o linka\n"\
"  -v             Genera messaggi estesi durante la compilazione\n"\
"  -V             Visualizza la versione del compilatore and esce\n"\
"  -Wl,<opzioni>  Passa  (separate da virgola) al linker\n"\
"  -x             Genera un modulo eseguibile\n"\
"  -z             Genera messaggi molto estesi durante la compilazione\n"\
"Opzioni specifiche COBOL:\n"\
"  -C             Rendi tutte le 'calls' COBOL dinamiche\n"\
"  -D             Includi le linee di sorgente per il debugging\n"\
"  -F             Il sorgente in ingresso e` formattato in modalita` standard (fixed column)\n"\
"  -I <dir>       Definisce le cartelle 'path' di ricerca delle 'include' (copybooks).\n"\
"                 Il percorso puo` essere sia una singola cartella, sia un elenco di\n"\
"                 cartelle separate da ':' (';' su piattaforma Win32).\n"\
"                 La cartella di ricerca di default e` la cartella corrente (./).\n"\
"  -P             Genera un listato di compilazione\n"\
"  -T <num>       Converti i 'tabs' in 'num' spazi (default T=8)\n"\
"  -X             Il sorgente in ingresso ha la formattazione libera (X/Open free format) (default format)\n"\
"\n"
#endif

#ifdef TCOB_LANGUAGE_pt_BR

#define HTG_OPTIONS     "Opcoes especificas do Compilador:\n"\
"  -h             Mostra ajuda\n"\
"  -a             Cria biblioteca estatica; pre-processa, compila, assembla e arquiva\n"\
"  -B <modo>      modo especifico para aglutinacao (estatica/dinamica)\n"\
"  -c             Compilacao para um modulo de objeto estaticamente linkado\n"\
"  -e <name>      Specify entry point name (first program to execute)\n"\
"  -E             Saida do preprocessador para saida padrao apenas; nao compila, assembla ou linka\n"\
"  -g             Gera saida de debug de compilacao\n"\
"  -l <arquivo>   Adiciona biblioteca na linkedicao\n"\
"  -L <diretorio> Adiciona diretorio ao caminho de procura de bibliotecas\n"\
"  -m <arquivo>   Cria biblioteca dinamica; pre-processa, compila, assembla e linka\n"\
"  -M <option>    Specify main entry point option (auto|first|none)\n"\
"  -n             Na~o executa nenhum comando, deve mostrar a compilacao\n"\
"  -o <arquivo>   Especifica nome do executavel (padrao de entrada x extensao)\n"\
"  -S             Preprocessa, compila(gera codigo assembler) somente; nao assembla ou linka\n"\
"  -v             Gera saida do compilador verbosa\n"\
"  -V             Mostra informacoes da versao do compilador e sai\n"\
"  -Wl,<opcoes>   Passar opcoes separadas por virgula ao linkeditor\n"\
"  -x             Compilacao para criar um executavel\n"\
"  -z             Gera saida do compilador verbosa\n"\
"Opcoes especificas do COBOL:\n"\
"  -C             Faz todas as chamadas dinamicas COBOL\n"\
"  -D             Inclui linhas de debug no fonte\n"\
"  -F             Fonte de entrada esta em formato de coluna fixa padrao\n"\
"  -I <diretorio> Define inclusao(copybooks) de caminhos de procura. (padrao -I./)\n"\
"                 O caminho pode ser um simples diretorio, ou uma lista de diretorios separados por um ':'\n"\
"  -P             Gera arquivo de saida listado\n"\
"  -T <num>       <Expande tabs para um numero de espacos (padrao T=8)\n"\
"  -X             Arquivo de entrada esta em formato livre X/Open (formato padrao)\n"\
"\n"
#endif

#ifdef TCOB_LANGUAGE_es

#define HTG_OPTIONS     "Opciones especficas del compilador:\n"\
"  -h             Ayuda (muestra este listado)\n"\
"  -a             Crea una librera esttica; Preprocesar, compilar, ensamblar y archivar\n"\
"  -B <mode>      Especificar el modo para enlazado (static o dynamic)\n"\
"  -c             Proprocesa, compila y ensambla, pero no enlaza\n"\
"  -e <name>      Specify entry point name (first program to execute)\n"\
"  -E             Muestra solo la salida del preprocesador a salida estandard; no compila, ensambla o enlaza\n"\
"  -g             Generar salida de compilador para debug\n"\
"  -l <name>      Aade la librera al enlazado\n"\
"  -L <dir>       Aade el directorio al camino de bsqueda de libreras\n"\
"  -m <name>      Crea una librera compartida; Preprocesa, compila, ensambla y enlaza\n"\
"  -M <option>    Specify main entry point option (auto|first|none)\n"\
"  -n             No ejecuta ningn comando; solo los muestra\n"\
"  -o <file>      Especifica el nombre del fichero de salida\n"\
"  -S             Solo preprocesar y compilar (genera ensablador); no ensambla o enlaza\n"\
"  -v             Genera salida del compilador detallada\n"\
"  -V             Muestra la versin del compilador y termina\n"\
"  -Wl,<options>  Pasa <opciones>, separadas por comas, al enlazador\n"\
"  -x             Crea un ejecutable; preprocesa, compila, ensambla y enlaza\n"\
"  -z             Genera la salida del compilador muy detallada\n"\
"Opciones especficas de COBOL:\n"\
"  -C             Hace todas las llamadas de COBOL dinmicas\n"\
"  -D             Incluye lineas del fuente para debug\n"\
"  -F             El fuente de entrada est en formato estndar de columnas fijas\n"\
"  -I <dir>       Aade el directorio al final del camino de bsqueda de copybooks\n"\
"  -P             Genera un fichero listado de la salida\n"\
"  -T <num>       Expande los tabuladores a un nmero de espacios (por defecto T=8)\n"\
"  -X             El fichero de entrada est en formato libre X/Open (formato por defecto)\n"\
"\n"
#endif

#endif
